==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/speech/translations/speech_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Mowa</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maksymalna liczba wymówionych liter</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Wiadomość za długa (forma męska)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Wiadomość za krótka (forma żeńska)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Głos</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Częstotliwość bazowa</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>System dźwiękowy</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Eds</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Urządzenie DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntezator Klatta (wymaga DSP)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Program do obsługi mowy</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Przeczytaj tekst</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Forma męska</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Forma żeńska</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/speech/translations/speech_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Mowa</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maksymalna liczba wymówionych liter</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Wiadomość za długa (forma męska)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Wiadomość za krótka (forma żeńska)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Głos</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Częstotliwość</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Częstotliwość bazowa</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodia</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>System dźwiękowy</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Eds</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>DSP</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Urządzenie DSP</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Syntezator Klatta (wymaga DSP)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Program do obsługi mowy</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Przeczytaj tekst</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Forma męska</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Forma żeńska</translation>
    </message>
</context>
</TS>
